summaryrefslogtreecommitdiffstats
path: root/kmailcvt/filter_pmail.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'kmailcvt/filter_pmail.cxx')
-rw-r--r--kmailcvt/filter_pmail.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmailcvt/filter_pmail.cxx b/kmailcvt/filter_pmail.cxx
index 23617f91..126a6365 100644
--- a/kmailcvt/filter_pmail.cxx
+++ b/kmailcvt/filter_pmail.cxx
@@ -81,13 +81,13 @@ void FilterPMail::import(FilterInfo *info)
info->setOverall(100);
}
-/** this looks for all files with the filemask 'mask' and calls the 'workFunc' on each of them */
-void FilterPMail::processFiles(const TQString& mask, void(FilterPMail::* workFunc)(const TQString&) )
+/** this looks for all files with the filetqmask 'tqmask' and calls the 'workFunc' on each of them */
+void FilterPMail::processFiles(const TQString& tqmask, void(FilterPMail::* workFunc)(const TQString&) )
{
if (inf->shouldTerminate()) return;
- TQStringList files = dir.entryList(mask, TQDir::Files, TQDir::Name);
- //kdDebug() << "Mask is " << mask << " count is " << files.count() << endl;
+ TQStringList files = dir.entryList(tqmask, TQDir::Files, TQDir::Name);
+ //kdDebug() << "Mask is " << tqmask << " count is " << files.count() << endl;
for ( TQStringList::Iterator mailFile = files.begin(); mailFile != files.end(); ++mailFile ) {
// Notify current file
TQFileInfo mailfileinfo(*mailFile);
@@ -186,7 +186,7 @@ void FilterPMail::importMailFolder(const TQString& file)
f.at(f.at() - l + 1);
}
- // no problem to loose the last line in file. This only contains a seperate char
+ // no problem to loose the last line in file. This only tqcontains a seperate char
while ( ! f.atEnd() && (l = f.readLine(input.data(),MAX_LINE))) {
if (inf->shouldTerminate()){
tempfile.close();
@@ -228,8 +228,8 @@ void FilterPMail::importUnixMailFolder(const TQString& file)
int n = 0, l = 0;
/** Get the folder name */
- s.replace( TQRegExp("mbx$"), "pmg");
- s.replace( TQRegExp("MBX$"), "PMG");
+ s.tqreplace( TQRegExp("mbx$"), "pmg");
+ s.tqreplace( TQRegExp("MBX$"), "PMG");
f.setName(s);
if (! f.open( IO_ReadOnly ) ) {
inf->alert( i18n("Unable to open %1, skipping").arg( s ) );